pub fn render_success(outcome: &BootstrapOutcome, args: &BootstrapArgs)Expand description
Render the outcome to stdout, honouring the requested format. This is the only place the dispatcher prints success output.
pub fn render_success(outcome: &BootstrapOutcome, args: &BootstrapArgs)Render the outcome to stdout, honouring the requested format. This is the only place the dispatcher prints success output.