pub struct ControlPlaneIndex(pub u64);Expand description
A position in the control-plane log. The log is append-only and totally ordered, so an index uniquely names one committed control-plane fact.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for ControlPlaneIndex
impl Clone for ControlPlaneIndex
Sourcefn clone(&self) -> ControlPlaneIndex
fn clone(&self) -> ControlPlaneIndex
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ControlPlaneIndex
Sourceimpl Debug for ControlPlaneIndex
impl Debug for ControlPlaneIndex
impl Eq for ControlPlaneIndex
Sourceimpl Hash for ControlPlaneIndex
impl Hash for ControlPlaneIndex
Sourceimpl Ord for ControlPlaneIndex
impl Ord for ControlPlaneIndex
Sourcefn cmp(&self, other: &ControlPlaneIndex) -> Ordering
fn cmp(&self, other: &ControlPlaneIndex) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ControlPlaneIndex
impl PartialEq for ControlPlaneIndex
Sourcefn eq(&self, other: &ControlPlaneIndex) -> bool
fn eq(&self, other: &ControlPlaneIndex) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ControlPlaneIndex
impl PartialOrd for ControlPlaneIndex
impl StructuralPartialEq for ControlPlaneIndex