migrate_store_to_binary_body

Function migrate_store_to_binary_body 

pub fn migrate_store_to_binary_body(
    store_dir: &Path,
) -> RedDBResult<MigrationReport>
Migrate the DOCUMENT collections of the store in store_dir to the native binary body, reversibly.

On success the store at store_dir holds the migrated (binary-body) files and the pre-migration files are retained at the returned MigrationReport::backup_dir. On any failure before the swap, the source store is left exactly as it was and the partially-built migrated directory is removed.