McpServer

Struct McpServer 

pub struct McpServer { /* private fields */ }
MCP server wrapping an embedded RedDB runtime.

Implementations

Source

impl McpServer

pub fn new(runtime: RedDBRuntime) -> Self

Create a new MCP server with the given runtime.

pub fn run_stdio(&mut self)

Run the MCP server reading from stdin and writing to stdout.

This blocks until stdin is closed (EOF). Diagnostic messages are written to stderr so they do not interfere with the protocol.