ControlPlaneLogIndex

Type Alias ControlPlaneLogIndex 

pub type ControlPlaneLogIndex = u64;
Position of an entry in the control-plane log. Monotonic per term-history; an entry is durable once its index is at or below the committed index of a quorum.