pub struct BackupScheduler { /* private fields */ }Expand description
Backup scheduler that runs periodic snapshots in a background thread.
Implementations
Sourceimpl BackupScheduler
impl BackupScheduler
Sourcepub fn start<F>(&self, backup_fn: F)
pub fn start<F>(&self, backup_fn: F)
Start the scheduler background thread.
The backup_fn is called each interval to perform the actual backup.
Sourcepub fn set_interval(&self, secs: u64)
pub fn set_interval(&self, secs: u64)
Update the backup interval.
Sourcepub fn record_backup(&self, result: BackupResult)
pub fn record_backup(&self, result: BackupResult)
Record a manual backup result.
Sourcepub fn status(&self) -> BackupStatus
pub fn status(&self) -> BackupStatus
Get current status.
Sourcepub fn is_running(&self) -> bool
pub fn is_running(&self) -> bool
Check if scheduler is running.