pub struct SignedFields {
pub signer_pubkey: [u8; 32],
pub signature: Vec<u8>,
}Expand description
Optional signer fields included in the hash preimage when the collection
has SIGNED_BY (...) declared. Issue #520 supplies the signer registry;
the chain hash binds the signature so a replaced signature also breaks the
chain.
Fields
signer_pubkey: [u8; 32]signature: Vec<u8>Trait Implementations
Sourceimpl Clone for SignedFields
impl Clone for SignedFields
Sourcefn clone(&self) -> SignedFields
fn clone(&self) -> SignedFields
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SignedFields
impl Debug for SignedFields
Sourceimpl PartialEq for SignedFields
impl PartialEq for SignedFields
Sourcefn eq(&self, other: &SignedFields) -> bool
fn eq(&self, other: &SignedFields) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for SignedFields
impl StructuralPartialEq for SignedFields