pub struct BgWriterStats {
pub rounds: AtomicU64,
pub pages_flushed: AtomicU64,
pub max_round_hit: AtomicU64,
pub last_dirty_fraction_milli: AtomicU64,
}Expand description
Diagnostic counters published by the background writer for monitoring / EXPLAIN ANALYZE-style introspection.
Fields
rounds: AtomicU64Total scan rounds executed since startup.
pages_flushed: AtomicU64Total pages flushed since startup.
max_round_hit: AtomicU64Total times the writer exited a round early because
it hit max_pages_per_round.
last_dirty_fraction_milli: AtomicU64Last reported dirty fraction (×1000 to keep it integer).
Implementations
Sourceimpl BgWriterStats
impl BgWriterStats