pub struct WeaklyConnectedComponents;Expand description
Weakly connected components - treats directed graph as undirected
A weakly connected component is a set of nodes where there is a path between any two nodes when ignoring edge direction.
Implementations
Sourceimpl WeaklyConnectedComponents
impl WeaklyConnectedComponents
Sourcepub fn find(graph: &GraphStore) -> WCCResult
pub fn find(graph: &GraphStore) -> WCCResult
Find all weakly connected components