decode

Function decode 

pub fn decode(pager: &Pager, stored: &[u8]) -> Result<Vec<u8>, ValueLayoutError>
Inspect leaf-cell flags, follow the pointer if any, concatenate the chain, decode if compressed, return the materialised value.