pub enum MetadataValue {
String(String),
Integer(i64),
Float(f64),
Bool(bool),
Null,
}Expand description
A metadata value that can be one of several types
Variants
String(String)
String value
Integer(i64)
Integer value
Float(f64)
Floating point value
Bool(bool)
Boolean value
Null
Null value
Implementations
Sourceimpl MetadataValue
impl MetadataValue
Sourcepub fn matches_eq(&self, other: &MetadataValue) -> bool
pub fn matches_eq(&self, other: &MetadataValue) -> bool
Check if this value matches another for equality
Sourcepub fn compare(&self, other: &MetadataValue) -> Option<Ordering>
pub fn compare(&self, other: &MetadataValue) -> Option<Ordering>
Compare for ordering (returns None for incompatible types)
Sourcepub fn contains_str(&self, needle: &str) -> bool
pub fn contains_str(&self, needle: &str) -> bool
Check if this string value contains a substring
Sourcepub fn starts_with(&self, prefix: &str) -> bool
pub fn starts_with(&self, prefix: &str) -> bool
Check if this string value starts with a prefix