pub async fn read_frame<R: AsyncRead + Unpin>(
stream: &mut R,
) -> Result<FrontendMessage, PgWireError>Expand description
Read a regular tagged frame after the startup handshake.
pub async fn read_frame<R: AsyncRead + Unpin>(
stream: &mut R,
) -> Result<FrontendMessage, PgWireError>Read a regular tagged frame after the startup handshake.